*Regolamento*

*1:* Non è possibile utilizzare il bot per *pubblicare messaggi offensivi*

*2:* Non è possibile *pubblicizzare o spammare*

*3:* Non è possibile utilizzare il bot per pubblicare foto o video in cui appaiono *volti non censurati* o messaggi audio contenenti *nome e cognome* per intero

*4:* Si consiglia fortemente di porre dubbi e domande specifiche per una materia negli appositi [gruppi Telegram](https://telegram\.unictdev\.org)

*5:* È vietato perseguitare o attaccare in modo persistsente un individuo, anche se in maniera anonima o abbreviata, mediante l'uso di spot

*6:* È fortemente sconsigliato l'invio di spot copypasta, spot con piccole variazioni o risposte dirette a spot precedenti

*7:* È fortemente sconsigliato l'uso di abbreviazioni, forme semplificate, sincopate ed apocopate

*8:* È fortemente sconsigliato l'invio di post *low\-effort*, *cringe*, *off\-topic* o *spoiler*  \(Per la soggettività della cosa vedi regola 9\)

*9:* Gli amministratori si riservano la soggettività di rifiutare qualsiasi spot anche se rientra nelle regole stabilite, se ritengono che ciò sia necessario per prevenire situazioni di flame o comportamenti dannosi per la comunità; la regola vale anche al contrario

*10:* Le regole elencate sopra valgono anche per i singoli commenti agli spot che, se necessario, verranno cancellati
